Class: Azure::Authorization::Mgmt::V2015_07_01::ProviderOperationsMetadataOperations

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb

Overview

Role based access control provides you a way to apply granular level policy administration down to individual resources or resource groups. These operations enable you to manage role definitions and role assignments. A role definition describes the set of actions that can be performed on resources. A role assignment grants access to Azure Active Directory users.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ ProviderOperationsMetadataOperations

Creates and initializes a new instance of the ProviderOperationsMetadataOperations class.



21
22
23
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 21

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientAuthorizationManagementClient (readonly)



26
27
28
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 26

def client
  @client
end

Instance Method Details

#get(resource_provider_namespace, api_version, expand: 'resourceTypes', custom_headers: nil) ⇒ ProviderOperationsMetadata

Gets provider operations metadata for the specified resource provider.

provider. will be added to the HTTP request.



40
41
42
43
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 40

def get(resource_provider_namespace, api_version, expand:'resourceTypes', custom_headers:nil)
  response = get_async(resource_provider_namespace, api_version, expand:expand, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_provider_namespace, api_version, expand: 'resourceTypes', custom_headers: nil) ⇒ Concurrent::Promise

Gets provider operations metadata for the specified resource provider.

provider. to the HTTP request.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 73

def get_async(resource_provider_namespace, api_version, expand:'resourceTypes', custom_headers:nil)
  fail ArgumentError, 'resource_provider_namespace is nil' if resource_provider_namespace.nil?
  fail ArgumentError, 'api_version is nil' if api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'providers/Microsoft.Authorization/providerOperations/{resourceProviderNamespace}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'resourceProviderNamespace' => resource_provider_namespace},
      query_params: {'api-version' => api_version,'$expand' => expand},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Authorization::Mgmt::V2015_07_01::Models::.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_provider_namespace, api_version, expand: 'resourceTypes', custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets provider operations metadata for the specified resource provider.

provider. will be added to the HTTP request.



57
58
59
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 57

def get_with_http_info(resource_provider_namespace, api_version, expand:'resourceTypes', custom_headers:nil)
  get_async(resource_provider_namespace, api_version, expand:expand, custom_headers:custom_headers).value!
end

#list(api_version, expand: 'resourceTypes', custom_headers: nil) ⇒ Array<ProviderOperationsMetadata>

Gets provider operations metadata for all resource providers.

will be added to the HTTP request.



134
135
136
137
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 134

def list(api_version, expand:'resourceTypes', custom_headers:nil)
  first_page = list_as_lazy(api_version, expand:expand, custom_headers:custom_headers)
  first_page.get_all_items
end

#list_as_lazy(api_version, expand: 'resourceTypes', custom_headers: nil) ⇒ ProviderOperationsMetadataListResult

Gets provider operations metadata for all resource providers.

will be added to the HTTP request.

pages of the response.



311
312
313
314
315
316
317
318
319
320
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 311

def list_as_lazy(api_version, expand:'resourceTypes', custom_headers:nil)
  response = list_async(api_version, expand:expand, custom_headers:custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_page_link|
      list_next_async(next_page_link, custom_headers:custom_headers)
    end
    page
  end
end

#list_async(api_version, expand: 'resourceTypes', custom_headers: nil) ⇒ Concurrent::Promise

Gets provider operations metadata for all resource providers.

to the HTTP request.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 163

def list_async(api_version, expand:'resourceTypes', custom_headers:nil)
  fail ArgumentError, 'api_version is nil' if api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'providers/Microsoft.Authorization/providerOperations'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      query_params: {'api-version' => api_version,'$expand' => expand},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Authorization::Mgmt::V2015_07_01::Models::ProviderOperationsMetadataListResult.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers: nil) ⇒ ProviderOperationsMetadataListResult

Gets provider operations metadata for all resource providers.

to List operation. will be added to the HTTP request.



222
223
224
225
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 222

def list_next(next_page_link, custom_headers:nil)
  response = list_next_async(next_page_link, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise

Gets provider operations metadata for all resource providers.

to List operation. to the HTTP request.



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 251

def list_next_async(next_page_link, custom_headers:nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Authorization::Mgmt::V2015_07_01::Models::ProviderOperationsMetadataListResult.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets provider operations metadata for all resource providers.

to List operation. will be added to the HTTP request.



237
238
239
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 237

def list_next_with_http_info(next_page_link, custom_headers:nil)
  list_next_async(next_page_link, custom_headers:custom_headers).value!
end

#list_with_http_info(api_version, expand: 'resourceTypes', custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Gets provider operations metadata for all resource providers.

will be added to the HTTP request.



149
150
151
# File 'lib/2015-07-01/generated/azure_mgmt_authorization/provider_operations_metadata_operations.rb', line 149

def list_with_http_info(api_version, expand:'resourceTypes', custom_headers:nil)
  list_async(api_version, expand:expand, custom_headers:custom_headers).value!
end